@@ -1,5 +1,5 @@
 from functools import lru_cache
-from typing import Dict, List, Optional
+from typing import Dict, List, Literal, Optional
 
 import numpy as np
 import pandas as pd
@@ -370,7 +370,7 @@ class SETSignalCreator:
     def rank(
         factor_df: pd.DataFrame,
         quantity: Optional[int] = None,
-        method: str = "first",
+        method: Literal["average", "min", "max", "first", "dense"] = "first",
         ascending: bool = True,
         pct: bool = False,
     ):
@@ -472,7 +472,7 @@ class SETSignalCreator:
         self, df: pd.DataFrame, fill_value=None
     ) -> pd.DataFrame:
         s = self._get_symbol_in_universe()
-        return df.reindex(columns=s, fill_value=fill_value)  # type: ignore
+        return df.reindex(columns=s, fill_value=fill_value)
 
     def _rolling(
         self,
@@ -530,7 +530,7 @@ class SETSignalCreator:
 
         return self._sdr.get_symbols_by_index(
             index_list=[index],
-            start_date=start_as_of_dict[index],
+            start_date=start_as_of_dict.get(index),
             end_date=self._end_date,
         )
 
@@ -553,7 +553,7 @@ class SETSignalCreator:
         df = pd.DataFrame(is_uni_dict, index=pd.DatetimeIndex(tds))
 
         # Reindex columns
-        df = df.reindex(columns=sorted(df.columns))  # type: ignore
+        df = df.reindex(columns=sorted(df.columns))
 
         return df
 
@@ -607,34 +607,30 @@ class SETSignalCreator:
             sign_list=["SP"],
         )
 
-        # hold_date and release_date can be with time
-        df["hold_date"] = df["hold_date"].dt.normalize()  # type: ignore
-        df["release_date"] = df["release_date"].dt.normalize()  # type: ignore
+        tds = self._get_trading_dates()
+        df = df.fillna({"release_date": pd.Timestamp(tds[-1]) + pd.Timedelta(days=1)})
 
-        df["true"] = 1
-        df["false"] = 0
-
-        # pivot_table also drop duplicated index
-        df_hold = df.pivot_table(index="hold_date", columns="symbol", values="true")
-        df_release = df.pivot_table(
-            index="release_date", columns="symbol", values="false"
+        # closed="left" because at hold date is not tradable but release date is tradable
+        df["date_range"] = df.apply(
+            lambda x: pd.bdate_range(
+                start=x["hold_date"], end=x["release_date"], closed="left"
+            ),  # type: ignore
+            axis=1,
+            result_type="reduce",
+        )
+        date_range_group = df.groupby("symbol")["date_range"].apply(
+            lambda x: utils.union_datetime_index(x)
         )
 
-        df_hold, df_release = df_hold.align(df_release)
-        assert isinstance(df_release, pd.DataFrame)
-        assert isinstance(df_hold, pd.DataFrame)
-
-        df = df_release.fillna(df_hold)
-        df.index.name = None
-        df.columns.name = None
+        out = pd.DataFrame(
+            [pd.Series(True, index=v, name=k) for k, v in date_range_group.items()]
+        ).T
 
         # Reindex
-        df = self._reindex_trade_date(df, method="ffill", fill_value=0)
-        df = self._reindex_columns_symbol(df, fill_value=0)
+        out = self._reindex_trade_date(out, fill_value=False)
+        out = self._reindex_columns_symbol(out, fill_value=False)
 
-        df = df.astype(bool)
-
-        return df
+        return out
 
     """
     Static methods
@@ -642,7 +638,10 @@ class SETSignalCreator:
 
     @staticmethod
     def _reindex_date(
-        df: pd.DataFrame, index, method: Optional[str] = None, fill_value=None
+        df: pd.DataFrame,
+        index,
+        method: Optional[Literal["backfill", "bfill", "ffill", "pad"]] = None,
+        fill_value=None,
     ) -> pd.DataFrame:
         """Reindex and fillna with method and fill_value."""
         index = pd.DatetimeIndex(index)
@@ -650,11 +649,11 @@ class SETSignalCreator:
         start = pd.Series([df.index.min(), index.min()]).min()
         end = pd.Series([df.index.max(), index.max()]).max()
         dr = pd.date_range(start=start, end=end)
-        df = df.reindex(dr)  # type: ignore
+        df = df.reindex(dr)
 
         if method != None:
-            df = df.fillna(method=method)  # type: ignore
+            df = df.fillna(method=method)
         if fill_value != None:
             df = df.fillna(fill_value)
 
-        return df.reindex(index=index)  # type: ignore
+        return df.reindex(index=index)
