@@ -54,7 +54,7 @@ def is_rebalance_weekly(
     pd.Series
         Series of bool. True if the date is a rebalance date.
     """
-    if not trade_date_index.is_monotonic or not trade_date_index.is_unique:
+    if not trade_date_index.is_monotonic or not trade_date_index.is_unique:  # type: ignore
         raise InputError("trade_date_index must be monotonic and unique")
     if rebalance_at < 1 or rebalance_at > 5:
         raise InputError("rebalance_at must be between 1 and 5")
@@ -84,7 +84,7 @@ def is_rebalance_monthly(
     pd.Series
         Series of bool, True if the date is a rebalance date.
     """
-    if not trade_date_index.is_monotonic or not trade_date_index.is_unique:
+    if not trade_date_index.is_monotonic or not trade_date_index.is_unique:  # type: ignore
         raise InputError("trade_date_index must be monotonic and unique")
     if rebalance_at < 1 or rebalance_at > 31:
         raise InputError("rebalance_at must be between 1 and 31")
@@ -143,6 +143,14 @@ def count_max_true_consecutive(s: pd.Series) -> int:
     return count_true_consecutive(s).max()
 
 
+def union_datetime_index(indexes: List[pd.DatetimeIndex]) -> pd.DatetimeIndex:
+    out = pd.DatetimeIndex([])
+    for i in indexes:
+        out = out.union(i)
+    assert isinstance(out, pd.DatetimeIndex)
+    return out
+
+
 """
 Cache
 """
